==> weba-0.0.15.tar.gz: weba-0.0.15/weba/tags.py <==
from dominate.svg import svg
from dominate.tags import dom_tag
from dominate.util import text

from .dominate_overrides import clean_attribute

dom_tag.clean_attribute = clean_attribute


def raw(s: str):
    """
    Inserts a raw string into the DOM. Unsafe. Alias for text(x, escape=False)
    """
    return text(s, escape=False)


from dominate.tags import (  # noqa: E402
    a,
    abbr,
    address,
    area,
    article,
    aside,
    audio,
    b,
    base,
    bdi,
    bdo,
    blockquote,
    body,
    br,
    button,
    canvas,
    caption,
    cite,
    code,
    col,
    colgroup,
    # data,
    datalist,
    dd,
    del_,
    details,
    dfn,
    # dialog,
    div,
    dl,
    # dom_tag,
    dt,
    em,
    embed,
    fieldset,
    figcaption,
    figure,
    footer,
    form,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    head,
    header,
    hgroup,
    hr,
    html,
    i,
    iframe,
    img,
    ins,
    kbd,
    keygen,
    label,
    legend,
    li,
    link,
    main,
    map_,
    mark,
    menu,
    # menuitem,
    meta,
    meter,
    nav,
    noscript,
    object_,
    ol,
    optgroup,
    option,
    output,
    p,
    param,
    # picture,
    pre,
    progress,
    q,
    rp,
    rt,
    ruby,
    s,
    samp,
    script,
    section,
    select,
    small,
    source,
    span,
    strong,
    style,
    sub,
    summary,
    sup,
    table,
    tbody,
    td,
    # template,
    textarea,
    tfoot,
    th,
    thead,
    time_,
    title,
    tr,
    track,
    u,
    ul,
    var,
    video,
    wbr,
)

# noqa: E402
from dominate.tags import (  # noqa: E402
    # NOTE: Yes input is a reserved function name in Python,
    # but it will never be used as a function in this context.
    input_ as input,
)

# __import__("dominate.tags", fromlist=["*"])

__all__ = [
    "a",
    "abbr",
    "address",
    "area",
    "article",
    "aside",
    "audio",
    "b",
    "base",
    "bdi",
    "bdo",
    "blockquote",
    "body",
    "br",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "col",
    "colgroup",
    # "data",
    "datalist",
    "dd",
    "del_",
    "details",
    "dfn",
    # "dialog",
    "div",
    "dl",
    "dt",
    "em",
    "embed",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "head",
    "header",
    "hgroup",
    "hr",
    "html",
    "i",
    "iframe",
    "img",
    "input",
    "ins",
    "kbd",
    "keygen",
    "label",
    "legend",
    "li",
    "link",
    "main",
    "map_",
    "mark",
    "menu",
    # "menuitem",
    "meta",
    "meter",
    "nav",
    "noscript",
    "object_",
    "ol",
    "optgroup",
    "option",
    "output",
    "p",
    "param",
    # "picture",
    "pre",
    "progress",
    "q",
    "rp",
    "rt",
    "ruby",
    "s",
    "samp",
    "script",
    "section",
    "select",
    "small",
    "source",
    "span",
    "strong",
    "style",
    "sub",
    "summary",
    "sup",
    "table",
    "tbody",
    "td",
    # "template",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time_",
    "title",
    "tr",
    "track",
    "u",
    "ul",
    "var",
    "video",
    "wbr",
    "raw",
    "svg",
]

==> weba-0.0.22.tar.gz: weba-0.0.22/weba/tags.py <==
import sys

import dominate.util  # noqa: F401

dominate_util_module = sys.modules["dominate.util"]

from .dominate_overrides import clean_attribute, escape  # noqa: E402

dominate_util_module.escape = escape  # type: ignore
dominate_util_module.str_escape = escape  # type: ignore

from dominate.svg import svg  # noqa: E402
from dominate.tags import dom_tag  # noqa: E402

dom_tag.clean_attribute = clean_attribute

text = dominate_util_module.text


def raw(s: str):
    """
    Inserts a raw string into the DOM. Unsafe. Alias for text(x, escape=False)
    """
    return dominate_util_module.text(s, escape=False)


from dominate.tags import (  # noqa: E402
    a,
    abbr,
    address,
    area,
    article,
    aside,
    audio,
    b,
    base,
    bdi,
    bdo,
    blockquote,
    body,
    br,
    button,
    canvas,
    caption,
    cite,
    code,
    col,
    colgroup,
    # data,
    datalist,
    dd,
    del_,
    details,
    dfn,
    # dialog,
    div,
    dl,
    # dom_tag,
    dt,
    em,
    embed,
    fieldset,
    figcaption,
    figure,
    footer,
    form,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    head,
    header,
    hgroup,
    hr,
    html,
    i,
    iframe,
    img,
    ins,
    kbd,
    keygen,
    label,
    legend,
    li,
    link,
    main,
    map_,
    mark,
    menu,
    # menuitem,
    meta,
    meter,
    nav,
    noscript,
    object_,
    ol,
    optgroup,
    option,
    output,
    p,
    param,
    # picture,
    pre,
    progress,
    q,
    rp,
    rt,
    ruby,
    s,
    samp,
    script,
    section,
    select,
    small,
    source,
    span,
    strong,
    style,
    sub,
    summary,
    sup,
    table,
    tbody,
    td,
    # template,
    textarea,
    tfoot,
    th,
    thead,
    time_,
    title,
    tr,
    track,
    u,
    ul,
    var,
    video,
    wbr,
)

# noqa: E402
from dominate.tags import (  # noqa: E402
    # NOTE: Yes input is a reserved function name in Python,
    # but it will never be used as a function in this context.
    input_ as input,
)

# __import__("dominate.tags", fromlist=["*"])

__all__ = [
    "a",
    "abbr",
    "address",
    "area",
    "article",
    "aside",
    "audio",
    "b",
    "base",
    "bdi",
    "bdo",
    "blockquote",
    "body",
    "br",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "col",
    "colgroup",
    # "data",
    "datalist",
    "dd",
    "del_",
    "details",
    "dfn",
    # "dialog",
    "div",
    "dl",
    "dt",
    "em",
    "embed",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "head",
    "header",
    "hgroup",
    "hr",
    "html",
    "i",
    "iframe",
    "img",
    "input",
    "ins",
    "kbd",
    "keygen",
    "label",
    "legend",
    "li",
    "link",
    "main",
    "map_",
    "mark",
    "menu",
    # "menuitem",
    "meta",
    "meter",
    "nav",
    "noscript",
    "object_",
    "ol",
    "optgroup",
    "option",
    "output",
    "p",
    "param",
    # "picture",
    "pre",
    "progress",
    "q",
    "rp",
    "rt",
    "ruby",
    "s",
    "samp",
    "script",
    "section",
    "select",
    "small",
    "source",
    "span",
    "strong",
    "style",
    "sub",
    "summary",
    "sup",
    "table",
    "tbody",
    "td",
    # "template",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time_",
    "title",
    "tr",
    "track",
    "u",
    "ul",
    "var",
    "video",
    "wbr",
    "raw",
    "svg",
]
